@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2017 by Dominique Dumont.
+# This software is Copyright (c) 2014-2018 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Dump the configuration of an application
 
 package App::Cme::Command::dump ;
-$App::Cme::Command::dump::VERSION = '1.026';
+$App::Cme::Command::dump::VERSION = '1.029';
 use strict;
 use warnings;
 use 5.10.1;
@@ -42,13 +42,12 @@ sub opt_spec {
             }
         ],
         [
-            "format=s" => "dump using specified format",
+            "format=s" => "dump using specified format (yaml json perl cml)",
             {
                 regex => qr/^(?:json|ya?ml|perl|cml|cds)$/i,
                 default => 'yaml'
             },
         ],
-        [ "quiet!"             => "Suppress progress messages" ],
         $class->cme_global_options,
     );
 }
@@ -105,7 +104,7 @@ App::Cme::Command::dump - Dump the configuration of an application
 
 =head1 VERSION
 
-version 1.026
+version 1.029
 
 =head1 SYNOPSIS
 
@@ -149,7 +148,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Dominique Dumont.
+This software is Copyright (c) 2014-2018 by Dominique Dumont.
 
 This is free software, licensed under:
 
