@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2017 by Dominique Dumont.
+# This software is Copyright (c) 2014-2018 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Edit the configuration of an application
 
 package App::Cme::Command::edit ;
-$App::Cme::Command::edit::VERSION = '1.026';
+$App::Cme::Command::edit::VERSION = '1.029';
 use strict;
 use warnings;
 use 5.10.1;
@@ -33,7 +33,6 @@ sub opt_spec {
         [ "ui|if=s"     => "user interface type. Either tk, curses, shell" ],
         [ "backup:s"  => "Create a backup of configuration files before saving." ],
         [ "open-item=s" => "open a specific item of the configuration" ],
-        [ "quiet!"      => "Suppress progress messages" ],
         $class->cme_global_options,
     );
 }
@@ -125,7 +124,7 @@ App::Cme::Command::edit - Edit the configuration of an application
 
 =head1 VERSION
 
-version 1.026
+version 1.029
 
 =head1 SYNOPSIS
 
@@ -180,10 +179,6 @@ See L<cme/"Global Options">.
 
 Open a specific item of the configuration when opening the editor
 
-=item -quiet
-
-Suppress porgress message
-
 =back
 
 =head1 SEE ALSO
@@ -196,7 +191,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Dominique Dumont.
+This software is Copyright (c) 2014-2018 by Dominique Dumont.
 
 This is free software, licensed under:
 
