@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2017 by Dominique Dumont.
+# This software is Copyright (c) 2014-2018 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Edit the configuration of an application with a shell
 
 package App::Cme::Command::shell ;
-$App::Cme::Command::shell::VERSION = '1.026';
+$App::Cme::Command::shell::VERSION = '1.029';
 use strict;
 use warnings;
 use 5.10.1;
@@ -30,7 +30,6 @@ sub opt_spec {
     return ( 
         [ "open-item=s" => "open a specific item of the configuration" ],
         [ "backup:s"  => "Create a backup of configuration files before saving." ],
-        [ "quiet!"      => "Suppress progress messages" ],
         [ "bare!"       => "run bare terminal UI"],
         $class->cme_global_options,
     );
@@ -78,7 +77,7 @@ App::Cme::Command::shell - Edit the configuration of an application with a shell
 
 =head1 VERSION
 
-version 1.026
+version 1.029
 
 =head1 SYNOPSIS
 
@@ -102,10 +101,6 @@ See L<cme/"Global Options">.
 
 Open a specific item of the configuration when opening the editor
 
-=item -quiet
-
-Suppress porgress message
-
 =item -bare
 
 Use Term UI without auto-completion or font enhancements.
@@ -122,7 +117,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Dominique Dumont.
+This software is Copyright (c) 2014-2018 by Dominique Dumont.
 
 This is free software, licensed under:
 
